@@ -88,12 +88,12 @@ void fx_chat_add_message(FxChat* fxchat , const char* msg
 	if(issendmsg == 0){
 		strftime(time, sizeof(time), "%H:%M:%S", datetime);
 		snprintf(text, sizeof(text) - 1,
-				_("%s said: (%s):\n"), contact->nickname, time);
+				_("%s says: (%s):\n"), contact->nickname, time);
 	}else{
 		now = get_currenttime();
 		strftime(time, sizeof(time), "%H:%M:%S", now);
 		snprintf(text, sizeof(text) - 1,
-				_("%s said: (%s):\n"), user->nickname, time);
+				_("%s says: (%s):\n"), user->nickname, time);
 		fx_main_add_history(fxmain, user->nickname,	contact->userId,
 				msg, issendmsg);
 	}
@@ -111,7 +111,7 @@ void fx_chat_add_message(FxChat* fxchat , const char* msg
 			if(strstr(pos , "#") != NULL){
 				n = strlen(pos) - strlen(strstr(pos , "#"));
 				if(n == 1 || n == 2 ){
-					bzero(num , sizeof(num));
+					memset(num, 0, sizeof(num));
 					strncpy(num , pos , n);
 					if(atoi(num) > 0 && atoi(num) < 53){
 						gtk_text_buffer_insert_with_tags_by_name(buffer
@@ -404,7 +404,10 @@ void fx_chat_initialize(FxChat* fxchat)
 
 	fxchat->dialog = gtk_window_new(GTK_WINDOW_TOPLEVEL);
 	gtk_window_set_modal(GTK_WINDOW(fxchat->dialog) , FALSE);
-	gtk_window_set_default_size(GTK_WINDOW(fxchat->dialog) , 600 , 430);
+	if(config->closeFetionShow == CLOSE_FETION_SHOW_DISABLE)
+		gtk_window_set_default_size(GTK_WINDOW(fxchat->dialog) , 600 , 430);
+	else
+		gtk_window_set_default_size(GTK_WINDOW(fxchat->dialog) , 550 , 430);
 	gtk_widget_set_size_request(fxchat->dialog , 550 , 0);
 	gtk_container_set_border_width(GTK_CONTAINER(fxchat->dialog) , 10);
 	fx_chat_update_window(fxchat);
@@ -518,6 +521,7 @@ void fx_chat_initialize(FxChat* fxchat)
 	pb = gdk_pixbuf_new_from_file_at_size(SKIN_DIR"history.png" , 16 , 16 , NULL);
 	history_icon = gtk_image_new_from_pixbuf(pb);
 	g_object_unref(pb);
+
 	fxchat->historybutton = gtk_toolbar_append_item(GTK_TOOLBAR(fxchat->toolbar)
 					 	, _("Chat logs") , _("View chat logs") , NULL , history_icon
 					  	, G_CALLBACK(fx_chat_on_history_clicked)
@@ -567,6 +571,9 @@ void fx_chat_initialize(FxChat* fxchat)
 	g_signal_connect(send_button , "clicked" , G_CALLBACK(fx_chat_on_send_clicked) , fxchat);
 
 	gtk_window_set_position(GTK_WINDOW(fxchat->dialog) , GTK_WIN_POS_CENTER);
+	gint x,y;
+	gtk_window_get_position(GTK_WINDOW(fxchat->dialog), &x, &y);
+	gtk_window_move(GTK_WINDOW(fxchat->dialog), x + rand()%100, y + rand()%100);
 	//gtk_window_set_opacity(GTK_WINDOW(fxchat->dialog) , 0.9);
 
 	fx_chat_bind(fxchat);
@@ -582,37 +589,40 @@ void fx_chat_initialize(FxChat* fxchat)
 
 	g_signal_connect(fxchat->dialog , "key-press-event" , G_CALLBACK(key_press_func) , fxchat);
 	/*right box */
+	if(config->closeFetionShow == CLOSE_FETION_SHOW_DISABLE){
+		frame = gtk_frame_new(NULL);
+		gtk_frame_set_shadow_type(GTK_FRAME(frame) , GTK_SHADOW_ETCHED_IN);
+		gtk_widget_set_usize(frame , 160 , 160);
 
-	frame = gtk_frame_new(NULL);
-	gtk_frame_set_shadow_type(GTK_FRAME(frame) , GTK_SHADOW_ETCHED_IN);
-	gtk_widget_set_usize(frame , 160 , 160);
+		sprintf(portraitPath , "%s/%s.jpg" , config->iconPath , contact->sId);
+		pb = gdk_pixbuf_new_from_file_at_size(portraitPath , 140 , 140 , NULL);
+		if(!pb)
+			pb = gdk_pixbuf_new_from_file_at_size(SKIN_DIR"fetion.svg" , 140 , 140 , NULL);
 
-	sprintf(portraitPath , "%s/%s.jpg" , config->iconPath , contact->sId);
-	pb = gdk_pixbuf_new_from_file_at_size(portraitPath , 140 , 140 , NULL);
-	if(!pb)
-		pb = gdk_pixbuf_new_from_file_at_size(SKIN_DIR"fetion.svg" , 140 , 140 , NULL);
+		img = gtk_image_new_from_pixbuf(pb);
+		g_object_unref(pb);
+		gtk_container_add(GTK_CONTAINER(frame) , img);
+		gtk_box_pack_start(GTK_BOX(rvbox) , frame , FALSE , FALSE , 0);
 
-	img = gtk_image_new_from_pixbuf(pb);
-	g_object_unref(pb);
-	gtk_container_add(GTK_CONTAINER(frame) , img);
-	gtk_box_pack_start(GTK_BOX(rvbox) , frame , FALSE , FALSE , 0);
+		GtkWidget *spliter = gtk_label_new(NULL);
+		gtk_box_pack_start(GTK_BOX(rvbox) , spliter , TRUE , TRUE , 0);
 
-	GtkWidget *spliter = gtk_label_new(NULL);
-	gtk_box_pack_start(GTK_BOX(rvbox) , spliter , TRUE , TRUE , 0);
-
-	frame = gtk_frame_new(NULL);
-	gtk_frame_set_shadow_type(GTK_FRAME(frame) , GTK_SHADOW_ETCHED_IN);
-	gtk_widget_set_usize(frame , 160 , 160);
-	bzero(portraitPath , sizeof(portraitPath));
-	sprintf(portraitPath , "%s/%s.jpg" , config->iconPath , user->sId);
-	pb = gdk_pixbuf_new_from_file_at_size(portraitPath , 140 , 140 , NULL);
-	if(!pb){
-		pb = gdk_pixbuf_new_from_file_at_size(SKIN_DIR"fetion.svg" , 140 , 140 , NULL);
+		frame = gtk_frame_new(NULL);
+		gtk_frame_set_shadow_type(GTK_FRAME(frame) , GTK_SHADOW_ETCHED_IN);
+		gtk_widget_set_usize(frame , 160 , 160);
+		sprintf(portraitPath , "%s/%s.jpg" , config->iconPath , user->sId);
+		pb = gdk_pixbuf_new_from_file_at_size(portraitPath , 140 , 140 , NULL);
+		if(!pb)
+			pb = gdk_pixbuf_new_from_file_at_size(SKIN_DIR"fetion.svg" , 140 , 140 , NULL);
+		
+		img = gtk_image_new_from_pixbuf(pb);
+		g_object_unref(pb);
+		gtk_container_add(GTK_CONTAINER(frame) , img);
+		gtk_box_pack_start(GTK_BOX(rvbox) , frame , FALSE , FALSE , 0);
 	}
-	img = gtk_image_new_from_pixbuf(pb);
-	g_object_unref(pb);
-	gtk_container_add(GTK_CONTAINER(frame) , img);
-	gtk_box_pack_start(GTK_BOX(rvbox) , frame , FALSE , FALSE , 0);
+
+	GTK_WIDGET_SET_FLAGS(fxchat->send_text, GTK_CAN_FOCUS);
+	gtk_widget_grab_focus(fxchat->send_text);
 
 	gtk_widget_show_all (vbox);
 	gtk_widget_show(fxchat->dialog);
@@ -653,7 +663,7 @@ void* fx_chat_send_message_thread(void *data)
 	gtk_text_buffer_get_end_iter(fxchat->send_buffer , &end);
 	text = gtk_text_buffer_get_text(fxchat->send_buffer , &begin , &end , TRUE);
 
-	if(strlen(text) == 0){
+	if(*text == '\0'){
 		fx_chat_add_information(fxchat,
 				_("Empty messages are not allowed."));
 		return NULL;
@@ -721,7 +731,7 @@ void fx_chat_send_message(FxChat* fxchat)
 	text = gtk_text_buffer_get_text(fxchat->send_buffer,
 			&begin, &end, TRUE);
 
-	if(strlen(text) == 0)
+	if(*text == '\0')
 		return;
 
 
@@ -732,7 +742,7 @@ void fx_chat_send_message(FxChat* fxchat)
 		text = gtk_text_buffer_get_text(fxchat->send_buffer,
 				&begin, &end, TRUE);
 
-		if(strlen(text) == 0){
+		if(*text == '\0'){
 			fx_chat_add_information(fxchat,
 					_("Empty messages are not allowed."));
 			return;
@@ -749,8 +759,8 @@ send:
 						" messages cannot be sent any more today."));
 				return;
 			}
-			sprintf(reason , _("You have %d free SMS can send "
-					" (include this one). Free SMS: %d per month")
+			sprintf(reason , _("%d free SMS messages can be sent(include this "
+					"one). Free SMS messages: %d per month")
 					, user->smsDayLimit - user->smsMonthCount
 					, user->smsMonthLimit );
 			sprintf(tips,
@@ -766,7 +776,7 @@ send:
 			if(ret == GTK_RESPONSE_OK){
 				code = gtk_entry_get_text(GTK_ENTRY(fxcode->codeentry));
 				user->verification->code = (char*)malloc(strlen(code) + 1);
-				bzero(user->verification->code , strlen(code) + 1);
+				memset(user->verification->code, 0, strlen(code) + 1);
 				strcpy(user->verification->code , code);
 				gtk_widget_destroy(fxcode->dialog);
 			}else{
@@ -890,6 +900,7 @@ static void fx_chat_on_nudge_clicked(GtkWidget* UNUSED(widget) , gpointer data)
 	fx_chat_nudge(fxchat);
 
 }
+
 void fx_chat_nudge(FxChat* fxchat)
 {
 	int x , y , i;
@@ -944,7 +955,7 @@ static void fx_chat_on_tophone_clicked(GtkWidget* widget , gpointer data)
 		fxchat->sendtophone = TRUE;
 
 		if(user->boundToMobile == BOUND_MOBILE_DISABLE){
-			bzero(text , sizeof(text));
+			memset(text, 0, sizeof(text));
 			if(user->smsDayLimit == user->smsDayCount
 			|| user->smsMonthLimit == user->smsMonthCount){
 				strcpy(text , _("Run out of your quota,"
@@ -961,8 +972,8 @@ static void fx_chat_on_tophone_clicked(GtkWidget* widget , gpointer data)
 			}
 			fx_chat_add_information(fxchat , text);
 		}else{
-			sprintf(text , _("Mesage will be sent to you phone as long SMS."
-						" You have sent %d, and %d left.")
+			sprintf(text , _("Messages will be sent to you phone as long SMS "
+						"messages. You have sent %d, and %d left.")
 					, user->smsDayCount , user->smsDayLimit - user->smsDayCount);
 			fx_chat_add_information(fxchat , text);
 		}
