@@ -27,6 +27,7 @@
 #include <net/if.h>
 #include <sys/socket.h>
 #include <netdb.h>
+#include <fx_server.h>
 
 int old_state;
 extern gint presence_count;
@@ -158,6 +159,19 @@ static void popup_startup_msg(FxMain *fxmain)
 #endif
 }
 
+static void *fx_server_func(void *data)
+{
+	FxMain *fxmain = (FxMain*)data;
+	int   fifo;
+
+	if((fifo = init_server(fxmain)) == -1) {
+		fprintf(stderr, "init openfetion server failed\n");
+		return (void*)0;
+	}
+	start_server(fxmain, fifo);
+	return (void*)0;
+}
+
 int fx_conn_connect(FxMain *fxmain)
 {
 	FxLogin          *fxlogin = fxmain->loginPanel;
@@ -238,7 +252,7 @@ login:
 	}
 	parse_ssi_auth_response(pos , user);
 	g_free(pos);
-	if(user->loginStatus == 421 || user->loginStatus == 420){
+	if(USER_AUTH_NEED_CONFIRM(user)){
 		debug_info(user->verification->text);
 		debug_info(user->verification->tips);
 		fx_login_show_msg(fxlogin,
@@ -267,19 +281,22 @@ login:
 		debug_info("Input verfication code:%s" , code);
 		goto login;
 	}
-	if(user->loginStatus == 401 ||
-	  	user->loginStatus == 400 ||
-	   	user->loginStatus == 404){
-		debug_info("password ERROR!!!");
+
+	if(USER_AUTH_ERROR(user)){
+		debug_error("password ERROR!!!");
 		fx_login_show_err(fxlogin,
-			_("Login failed. Incorrect cell phone number or password"));
+			_("Login failed. \nIncorrect cell phone number or password"));
 		goto failed;
 	}
 	
 	fx_login_show_err(fxlogin,
 				 _("Loading local user information"));
 
-	fetion_config_initialize(config , user->userId);
+	if(fetion_user_init_config(user) == -1) {
+		debug_error("initialize config failed");
+		fx_login_show_err(fxlogin , _("Login failed"));
+		goto failed;
+	}
 
 	/* initialize history */
 	fx_main_history_init(fxmain);
@@ -315,9 +332,8 @@ login:
 	fetion_config_load(user);
 	if(config->sipcProxyPort == 0)
 		fx_login_show_msg(fxlogin,
-					_("It detected that this`s"
-					" this first time you login\n"
-					"downloading configuration file..."));
+					_("Detected that this is the first time you login\n"
+					"Downloading configuration file..."));
 	else
 		fx_login_show_msg(fxlogin,
 					_("Downloading configuration files"));
@@ -372,6 +388,9 @@ login:
 	g_free(pos);
 
 	aeskey = generate_aes_key();
+	if(aeskey == NULL){
+		goto failed;
+	}
 	response = generate_response(nonce, user->userId,
 				   	user->password, key, aeskey);
 	g_free(nonce);
@@ -395,13 +414,13 @@ auth:
 	}
 	g_free(pos); pos = NULL;
 
-	if(user->loginStatus == 401 || user->loginStatus == 400){
+	if(USER_AUTH_ERROR(user)){
 		debug_info("Password error , login failed!!!");
 		fx_login_show_err(fxlogin , _("Authenticate failed."));
 		goto failed;
 	}
 
-	if(user->loginStatus == 421 || user->loginStatus == 420){
+	if(USER_AUTH_NEED_CONFIRM(user)){
 		debug_info(user->verification->text);
 		debug_info(user->verification->tips);
 		fx_login_show_msg(fxlogin,
@@ -474,10 +493,6 @@ auth:
 
 	fx_login_show_msg(fxlogin , _("Login sucessful"));
 
-	gdk_threads_enter();
-	gtk_window_set_resizable(GTK_WINDOW(fxmain->window) , TRUE);
-	gdk_threads_leave();
-
 	/*if there is not a buddylist name "Ungrouped" or "Strangers", create one */
 	if(fetion_group_list_find_by_id(user->groupList,
 			BUDDY_LIST_NOT_GROUPED) == NULL &&
@@ -513,6 +528,16 @@ auth:
 	fx_bottom_initialize(fxmain);
 	gdk_threads_leave();
 
+	gdk_threads_enter();
+	gtk_window_set_resizable(GTK_WINDOW(fxmain->window) , TRUE);
+	fetion_config_load_size(config);
+
+	if(config->window_width > 0 && config->window_height >0)
+		gtk_window_resize(GTK_WINDOW(fxmain->window),
+				config->window_width,
+				config->window_height);
+	gdk_threads_leave();
+
 	/* set tooltip of status icon */
 	sprintf(statusTooltip, "%s\n%s",
 			 user->nickname , user->mobileno);
@@ -534,8 +559,9 @@ auth:
 	gdk_threads_leave();
 
 	/* start sending keep alive request periodically */
-	g_timeout_add_seconds(60 , (GSourceFunc)fx_main_register_func , user);
-	g_timeout_add_seconds(3 , (GSourceFunc)fx_main_check_func , fxmain);
+	g_timeout_add_seconds(70 , (GSourceFunc)fx_main_register_func , user);
+	g_timeout_add_seconds(5 , (GSourceFunc)fx_main_check_func , fxmain);
+	g_thread_create(fx_server_func, fxmain, FALSE, NULL);
 
 	g_thread_exit(0);
 failed:
@@ -550,9 +576,7 @@ failed:
 
 void fx_conn_offline(FxMain *fxmain)
 {
-	FxHead           *fxhead;
 	FxTree           *fxtree;
-	User             *user;
 	GtkTreeView      *treeview;
 	GtkTreeModel     *model;
 	GtkTreeIter       rootiter;
@@ -564,9 +588,6 @@ void fx_conn_offline(FxMain *fxmain)
 	FxList           *tmp_cur;
 	FxChat           *fxchat;
 
-	fxhead = fxmain->headPanel;
-	user = fxmain->user;
-
 	/* set state image to be offline */
 	fx_head_set_state_image(fxmain, P_OFFLINE);
 	
@@ -697,6 +718,9 @@ int fx_conn_reconnect(FxMain *fxmain, int state)
 
 	/* generate sipc authencation response string */
 	aeskey = generate_aes_key();
+	if(aeskey == NULL){
+		goto failed2;
+	}
 	response = generate_response(nonce, user->userId,
 				   	user->password, key, aeskey);
 	g_free(nonce);
@@ -884,7 +908,11 @@ int fx_conn_offline_login(FxMain *fxmain)
 	/* set the config structure to user */
 	fetion_user_set_config(user , config);
 
-	fetion_config_initialize(config , user->userId);
+	if(fetion_user_init_config(user)) {
+		fx_login_show_err(fxlogin , _("Login failed"));
+		debug_error("initialize config failed");
+		goto failed1;
+	}
 	/* initialize history */
 	fx_main_history_init(fxmain);
 
