@@ -21,21 +21,21 @@ struct emotion emotions[] = {
 	{ N_("Sleeping Moon") , "(s)", 17 } ,
 	{ N_("Rain") , "(st)", 18 } ,
 	{ N_("Clock") , "(o)", 19 } ,
-	{ N_("Red heart") , "(l)", 20 } ,
-	{ N_("Broken heart") , "(u)", 21 } ,
-	{ N_("Face of cat") , "(@)", 22 } ,
-	{ N_("Face of dog") , "(&)", 23 } ,
+	{ N_("Red Heart") , "(l)", 20 } ,
+	{ N_("Broken Heart") , "(u)", 21 } ,
+	{ N_("Face of Cat") , "(@)", 22 } ,
+	{ N_("Face of Dog") , "(&)", 23 } ,
 	{ N_("Snail") , "(sn)", 24 } ,
 	{ N_("Star") , "(*)", 25 } ,
 	{ N_("Sun") , "(#)", 26 } ,
 	{ N_("Rainbow") , "(r)", 27 } ,
 	{ N_("Hug left") , "({)", 28 } ,
 	{ N_("Hug right") , "(})", 29 } ,
-	{ N_("Red lips") , "(k)", 30 } ,
-	{ N_("Red rose") , "(f)", 31 } ,
-	{ N_("Withered rose") , "(w)", 32 } ,
+	{ N_("Red Lips") , "(k)", 30 } ,
+	{ N_("Red Rose") , "(f)", 31 } ,
+	{ N_("Withered Rose") , "(w)", 32 } ,
 	{ N_("Gift Box") , "(g)", 33 } ,
-	{ N_("Birthday cake") , "(^)", 34 } ,
+	{ N_("Birthday Cake") , "(^)", 34 } ,
 	{ N_("Music") , "(8)", 35 } ,
 	{ N_("Bulb") , "(i)", 36 } ,
 	{ N_("Idea") , "*-:)", 37 } ,
@@ -132,7 +132,7 @@ void fx_emotion_initialize(FxEmotion *fxemotion , int x , int y)
 		for( i = 0 ; i < 10 ; i ++){
 			subframe = gtk_frame_new(NULL);
 			gtk_frame_set_shadow_type(GTK_FRAME(subframe) , GTK_SHADOW_ETCHED_IN);
-			bzero(path , sizeof(path));
+			memset(path, 0, sizeof(path));
 			if( k < 52 ){
 				sprintf(path , SKIN_DIR"face_images/%d.gif" , (k++) + 1);
 				img = gtk_image_new_from_file(path);
