@@ -26,6 +26,7 @@
 #include <sys/select.h>
 #include <locale.h>
 #include <glib.h>
+#include <fx_server.h>
 
 fd_set  fd_read;
 gint presence_count = 0;
@@ -36,6 +37,7 @@ gint window_pos_y_old = 0;
 gint start_popup_presence = 0;
 extern struct unacked_list *unackedlist;
 GStaticMutex mutex = G_STATIC_MUTEX_INIT;
+GdkScreen *current_screen;
 
 static void fx_main_process_pggetgroupinfo(FxMain *fxmain , const gchar *sipmsg);
 static void fx_main_process_pgpresencechanged(FxMain *fxmain , const gchar *sipmsg);
@@ -55,6 +57,7 @@ FxMain* fx_main_new()
 	fxmain->pglist = fx_list_new(NULL);
 	return fxmain;
 }
+
 #if 0
 static void fx_main_position_func(GtkWidget *UNUSED(widget) , GdkEventConfigure *event ,
                                     gpointer UNUSED(user_data)){
@@ -65,19 +68,27 @@ static void fx_main_position_func(GtkWidget *UNUSED(widget) , GdkEventConfigure
 
 void fx_main_initialize(FxMain* fxmain)
 {
-	int window_width , window_height;
-	GdkScreen *screen;
+	Config    *config;
 
 	fxmain->window = gtk_window_new(GTK_WINDOW_TOPLEVEL);
 	gtk_widget_set_name(fxmain->window , "mainwindow");
 	gtk_window_set_title(GTK_WINDOW(fxmain->window) , "OpenFetion");
 
 
-	screen = gdk_screen_get_default();
-	window_width = gdk_screen_get_width(screen);
-	window_height = gdk_screen_get_height(screen);
-	window_pos_x = window_width - WINDOW_WIDTH - 200;
-	window_pos_y = (window_height - WINDOW_HEIGHT) / 2;
+	current_screen = gdk_screen_get_default();
+	config = fetion_config_new();
+	fetion_config_load_size(config);
+	if(config->window_width == 0){
+		int window_width , window_height;
+		window_width = gdk_screen_get_width(current_screen);
+		window_height = gdk_screen_get_height(current_screen);
+		window_pos_x = window_width - WINDOW_WIDTH - 200;
+		window_pos_y = (window_height - WINDOW_HEIGHT) / 2;
+	}else{
+		window_pos_x = config->window_pos_x;
+		window_pos_y = config->window_pos_y;
+	}
+	fetion_config_free(config);
 
 	gtk_window_move(GTK_WINDOW(fxmain->window) , window_pos_x , window_pos_y);
 	gtk_container_set_border_width(GTK_CONTAINER(fxmain->window) , 0);
@@ -114,8 +125,11 @@ void fx_main_initialize(FxMain* fxmain)
 			SKIN_DIR"offline.svg");
 	gtk_status_icon_set_tooltip(fxmain->trayIcon, "OpenFetion");
 #ifdef USE_LIBNOTIFY
-	fxmain->notify = notify_notification_new_with_status_icon("welcome"
-			, "" , NULL , fxmain->trayIcon);
+	#ifdef LIBNOTIFY_OLD
+		fxmain->notify = notify_notification_new("welcome", "", SKIN_DIR"offline.svg", NULL);
+	#else
+		fxmain->notify = notify_notification_new("welcome", "", SKIN_DIR"offline.svg");
+	#endif
 	notify_notification_set_timeout(fxmain->notify , 2500);
 #endif
 
@@ -308,7 +322,7 @@ static void popup_online_notify(FxMain *fxmain, Contact *contact)
 				  "Signature: %s")
 				, contact->mobileno == NULL ||
 					strlen(contact->mobileno) == 0 ?
-					"未知" : contact->mobileno
+					_("unknown") : contact->mobileno
 				, contact->sId
 				, contact->impression );
 		pixbuf = gdk_pixbuf_new_from_file_at_size(
@@ -494,7 +508,7 @@ static void process_group_message(FxMain *fxmain , Message *message)
 		    }
 		}
 		sid = fetion_sip_get_pgid_by_sipuri(message->pguri);
-		snprintf(path , 1023 , "%s/PG%s.jpg" , config->iconPath , sid);
+		snprintf(path , sizeof(path) - 1 , "%s/PG%s.jpg" , config->iconPath , sid);
 		g_free(sid);
 		pixbuf = gdk_pixbuf_new_from_file(path , NULL);
 		if(pixbuf == NULL)
@@ -541,10 +555,12 @@ static void popup_msg_notify(FxMain *fxmain, Contact *senderContact, Message *ms
 			notify_notification_update(fxmain->notify,
 					notifySum, msg->message , NULL);
 
-			if(notifyIcon)
-				notify_notification_set_icon_from_pixbuf(
-						fxmain->notify , notifyIcon);
+			if(!notifyIcon)
+				notifyIcon = gdk_pixbuf_new_from_file_at_size(
+						SKIN_DIR"fetion.svg", 48, 48, NULL);
 
+			notify_notification_set_icon_from_pixbuf(
+						fxmain->notify , notifyIcon);
 			notify_notification_show(fxmain->notify , NULL);
 			g_object_unref(notifyIcon);
 		}
@@ -586,6 +602,8 @@ void fx_main_process_message(FxMain* fxmain , FetionSip* sip , const gchar* sipm
 	/* system message */
 	if(strlen(sid) < 5 || strcmp(sid , "10000") == 0){
 		g_free(sid);
+		if(config->closeSysMsg == CLOSE_SYSMSG_ENABLE)
+			return;
 		gdk_threads_enter();
 		process_system_message(sipmsg);
 		gdk_threads_leave();
@@ -718,7 +736,7 @@ FxChat* fx_main_create_chat_window(FxMain* fxmain , const gchar* sipuri)
 		if(!contact)
 			return NULL;
 		/* replace the sipuri*/
-		bzero(contact->sipuri , sizeof(contact->sipuri));
+		memset(contact->sipuri, 0, sizeof(contact->sipuri));
 		strcpy(contact->sipuri , sipuri);
 		fetion_contact_list_append(fxmain->user->contactList , contact);
 		conv = fetion_conversation_new(fxmain->user , sipuri , NULL);
@@ -746,8 +764,10 @@ void fx_main_process_invitation(FxMain* fxmain , const gchar* sipmsg)
 	sip = fxmain->user->sip;
 
 	memset(event, 0, sizeof(event));
-	if(fetion_sip_get_attr(sipmsg , "N" , event) != -1)
+	if(fetion_sip_get_attr(sipmsg , "N" , event) != -1){
+		free(args);
 		return;
+	}
 
 	fetion_sip_parse_invitation(sip,
 			fxmain->user->config->proxy,
@@ -907,11 +927,21 @@ void fx_main_process_sipc(FxMain* fxmain , const gchar* sipmsg)
 
 void fx_main_process_deregistration(FxMain* fxmain)
 {
-
 	gdk_threads_enter();
-	fx_util_popup_warning(fxmain , _("Your fetion login elsewhere. You are forced quit."));
+#ifdef USE_LIBNOTIFY
+	GdkPixbuf    *pixbuf;
+
+	pixbuf = gdk_pixbuf_new_from_file_at_size(
+				SKIN_DIR"fetion.svg",
+				NOTIFY_IMAGE_SIZE,
+				NOTIFY_IMAGE_SIZE, NULL);
+	notify_notification_update(fxmain->notify , "Sorry.."
+			, _("Your fetion login elsewhere. You are forced quit."), NULL);
+	notify_notification_set_icon_from_pixbuf(fxmain->notify , pixbuf);
+	notify_notification_show(fxmain->notify , NULL);
+	g_object_unref(pixbuf);
+#endif
 	gdk_threads_leave();
-	gtk_main_quit();
 }
 void fx_main_process_syncuserinfo(FxMain* fxmain , const gchar* xml)
 {
@@ -955,10 +985,10 @@ end:
 }
 void* fx_main_process_addbuddyapplication_thread(void* data)
 {
-	struct Args {
+	struct args1 {
 		FxMain *fxmain;
 		gchar   sipmsg[2048];
-	} *args = (struct Args*)data;
+	} *args = (struct args1*)data;
 	gchar *userid;
 	gchar *sipuri;
 	gchar *desc;
@@ -982,31 +1012,65 @@ void* fx_main_process_addbuddyapplication_thread(void* data)
 }
 void fx_main_process_addbuddyapplication(FxMain* fxmain , const char* sipmsg)
 {
-	struct Args{
+	struct args1 {
 		FxMain* fxmain;
 		char sipmsg[2048];
-	} *args = (struct Args*)malloc(sizeof(struct Args));
+	} *args = (struct args1*)malloc(sizeof(struct args1));
 
-	memset(args , 0 , sizeof(struct args));
+	memset(args , 0 , sizeof(struct args1));
 	args->fxmain = fxmain;
 	strcpy(args->sipmsg , sipmsg);
 	g_thread_create(fx_main_process_addbuddyapplication_thread , args , FALSE , NULL);
 }
-void fx_main_destroy(GtkWidget* UNUSED(widget) , gpointer UNUSED(data))
+void fx_main_destroy(GtkWidget* UNUSED(widget) , gpointer data)
 {
+	FxMain *fxmain = (FxMain*)data;
+	User   *user = fxmain->user;
+	char    server_fifo[128];
+	if(user){
+		Config *config = user->config;
+		fetion_config_save_size(config);
+		extern int idlefifo;
+		/* delete fifo file */
+		close(idlefifo);
+		snprintf(server_fifo, sizeof(server_fifo) - 1, OPENFETION_FIFO_FILE, user->mobileno);
+		unlink(server_fifo);
+	}
 	gtk_main_quit();
 }
 gboolean fx_main_delete(GtkWidget *widget , GdkEvent *UNUSED(event) , gpointer data)
 {
 	FxMain *fxmain = (FxMain*)data;
 	FxClose *fxclose;
-	Config *config;;
+	Config *config;
 
-	int ret;
+
+	int     window_width;
+	int     window_height;
+	int     window_x;
+	int     window_y;
+
+	printf("fx_main_delete\n");
+
+	if(!fxmain->window)
+		return TRUE;
 
 	if(fxmain->user){
 		config = fxmain->user->config;
+		gtk_window_get_position(GTK_WINDOW(fxmain->window),
+				&window_x, &window_y);
+		config->window_pos_x = window_x;
+		config->window_pos_y = window_y;
+		gtk_window_get_size(GTK_WINDOW(fxmain->window),
+				&window_width, &window_height);
+		config->window_width = window_width;
+		config->window_height = window_height;
+	}
+
+	if(fxmain->user){
 		if(config->closeAlert == CLOSE_ALERT_ENABLE){
+			int ret;
+
 			fxclose = fx_close_new(fxmain);
 			fx_close_initialize(fxclose);
 			ret = gtk_dialog_run(GTK_DIALOG(fxclose->dialog));
@@ -1032,7 +1096,7 @@ gboolean fx_main_delete(GtkWidget *widget , GdkEvent *UNUSED(event) , gpointer d
 			}
 		}
 	}else{
-		fx_main_destroy(widget , NULL);
+		fx_main_destroy(widget , fxmain);
 		return FALSE;
 	}
 
@@ -1048,6 +1112,7 @@ gboolean fx_main_delete(GtkWidget *widget , GdkEvent *UNUSED(event) , gpointer d
 	}
 	return FALSE;
 }
+
 gboolean fx_main_window_state_func(GtkWidget *widget
 		, GdkEventWindowState *event , gpointer data)
 {
@@ -1058,11 +1123,12 @@ gboolean fx_main_window_state_func(GtkWidget *widget
 	config = fxmain->user == NULL ? NULL: fxmain->user->config;
 
 	if(config){
-		if(event->new_window_state == GDK_WINDOW_STATE_ICONIFIED){
+			if(event->changed_mask == GDK_WINDOW_STATE_ICONIFIED && 
+				event->new_window_state == GDK_WINDOW_STATE_ICONIFIED){
+			
 			if(config->canIconify == ICON_CAN){
 				gtk_window_get_position(GTK_WINDOW(widget)
 						, &window_pos_x_old , &window_pos_y_old);
-				gtk_widget_hide(widget);
 				return TRUE;
 			}else{
 				return FALSE;
@@ -1071,6 +1137,7 @@ gboolean fx_main_window_state_func(GtkWidget *widget
 	}
 	return FALSE;
 }
+
 void fx_main_tray_activate_func(GtkWidget *UNUSED(widget) , gpointer data)
 {
 	FxMain *fxmain;
@@ -1090,6 +1157,7 @@ void fx_main_tray_activate_func(GtkWidget *UNUSED(widget) , gpointer data)
 			gtk_window_iconify(GTK_WINDOW(fxmain->window));
 			gtk_window_get_position(GTK_WINDOW(fxmain->window)
 					, &window_pos_x_old , &window_pos_y_old);
+			gtk_widget_hide(fxmain->window);
 		}
 	}
     else{
@@ -1160,8 +1228,8 @@ void fx_main_tray_popmenu_func(
 	typedef struct {
 		FxMain* fxmain;
 		StateType type;
-	} Args;
-	Args      *args;
+	} Args1;
+	Args1      *args;
 
 	fxmain = (FxMain*)data;
 	user = fxmain->user;
@@ -1186,10 +1254,6 @@ void fx_main_tray_popmenu_func(
 	menu = gtk_menu_new();
 	fx_main_create_menu1(_("About OpenFetion") , GTK_STOCK_ABOUT
 					 , menu , fx_main_about_fetion_clicked , NULL);
-	fx_main_create_menu1(_("About Authors") , GTK_STOCK_HOME
-					 , menu , fx_main_about_author_clicked , NULL);
-	fx_main_create_menu1(_("Look for new version") , GTK_STOCK_HELP
-					 , menu , fx_main_check_update_clicked , NULL);
 
 	if(fxmain->user && fxmain->user->loginStatus != -1)
 	{
@@ -1223,34 +1287,40 @@ void fx_main_tray_popmenu_func(
 		fx_main_create_menu1(_("Information query") , GTK_STOCK_FIND
 						 , menu , fx_main_info_lookup_clicked , fxmain);
 
-		if(fxmain->user->boundToMobile == BOUND_MOBILE_ENABLE)
-			fx_main_create_menu1(_("SMS myself") , GTK_STOCK_FILE
-							 , menu , fx_main_send_to_myself_clicked , fxmain);
 
 		statemenu = fx_main_create_menu1(_("Edit statement"),
 				GTK_STOCK_INFO , menu , NULL , NULL);
 
 		submenu = gtk_menu_new();
 		for(i = 0 ; presence[i].type != -1 ; i++){
-			args = (Args*)malloc(sizeof(Args));
+			args = (Args1*)malloc(sizeof(Args1));
 			args->fxmain = fxmain;
 			args->type = presence[i].type;
 
-			sprintf(stateMenu , "%s      " , _(presence[i].name));
+			sprintf(stateMenu , "%s      " , presence[i].name);
 			fx_main_create_menu(stateMenu , presence[i].icon
 							 , submenu , fx_main_set_state_clicked , args);
 		}
 
 		gtk_menu_item_set_submenu(GTK_MENU_ITEM(statemenu) , submenu);
-		fx_main_create_menu1(_("SMS to many") , GTK_STOCK_DND_MULTIPLE
-						 , menu , fx_main_send_to_many_clicked , fxmain);
-		fx_main_create_menu1(_("SMS directly") , GTK_STOCK_DND
-						 , menu , fx_main_direct_sms_clicked , fxmain);
+
+		statemenu = fx_main_create_menu1(_("Message Function"),
+				GTK_STOCK_INFO , menu , NULL , NULL);
+		submenu = gtk_menu_new();
+		fx_main_create_menu(_("SMS to many") , SKIN_DIR"groupsend.png" 
+						 , submenu , fx_main_send_to_many_clicked , fxmain);
+		fx_main_create_menu(_("SMS directly") , SKIN_DIR"directsms.png"
+						 , submenu , fx_main_direct_sms_clicked , fxmain);
+		if(fxmain->user->boundToMobile == BOUND_MOBILE_ENABLE)
+			fx_main_create_menu(_("SMS myself") , SKIN_DIR"myselfsms.png"
+							 , submenu , fx_main_send_to_myself_clicked , fxmain);
+		gtk_menu_item_set_submenu(GTK_MENU_ITEM(statemenu) , submenu);
+
 		fx_main_create_menu1(_("Add contact") , GTK_STOCK_ADD
 						 , menu , fx_main_add_buddy_clicked , fxmain);
-		fx_main_create_menu1(_("Personal setting") ,  GTK_STOCK_EDIT
+		fx_main_create_menu1(_("Personal Settings") ,  GTK_STOCK_EDIT
 						 , menu , fx_main_personal_setting_clicked , fxmain);
-		fx_main_create_menu1(_("System setting") , GTK_STOCK_PREFERENCES
+		fx_main_create_menu1(_("System Settings") , GTK_STOCK_PREFERENCES
 						 , menu , fx_main_system_setting_clicked , fxmain);
 	}
 
@@ -1262,14 +1332,22 @@ void fx_main_tray_popmenu_func(
 }
 int main(int argc , char* argv[])
 {
-
-	FxMain* fxmain = fx_main_new();
-
+#ifdef ENABLE_NLS
 	setlocale(LC_ALL, "");
 	bind_textdomain_codeset(GETTEXT_PACKAGE, "UTF-8");
 	bindtextdomain(GETTEXT_PACKAGE , LOCALE_DIR);
 	textdomain(GETTEXT_PACKAGE);
+#endif	
 
+	/* cli mode */
+	if(argc != 1) {
+		if(fx_cli_opt(argc, argv))
+			return 1;
+		return fx_cli_exec();
+	}
+
+	FxMain* fxmain = fx_main_new();
+	
 	if(!g_thread_supported())
 		g_thread_init(NULL);
 	gdk_threads_init();
@@ -1302,7 +1380,7 @@ static void chat_listen_thread_end(FxMain *fxmain, const char *sipuri)
 
 	clist = fxmain->clist;
 
-	if(!sipuri || strlen(sipuri) == 0)
+	if(!sipuri || *sipuri == '\0')
 		return;
 
 	fx_list_remove_sip_by_sipuri(fxmain->slist , sipuri);
@@ -1430,7 +1508,8 @@ void* fx_main_listen_thread_func(void* data)
 		if(msg)
 			fetion_sip_message_free(msg);
 	}
-
+	
+	free(data);
 	return NULL;
 }
 void fx_main_message_func(GtkWidget *UNUSED(widget) , gpointer data)
@@ -1464,7 +1543,6 @@ void fx_main_message_func(GtkWidget *UNUSED(widget) , gpointer data)
 			    g_print("%s:%s\n" , msg->sipuri ,  msg->message);
 			    continue;
 		    }
-
 		    fx_chat_add_message(fxchat , msg->message,
 					&(msg->sendtime) , 0 , msg->sysback);
 		}else{
@@ -1495,6 +1573,13 @@ void fx_main_message_func(GtkWidget *UNUSED(widget) , gpointer data)
 						 , "activate"
 						 , GTK_SIGNAL_FUNC(fx_main_tray_activate_func)
 						 , fxmain);
+
+	foreach_list(fxmain->clist, cur){
+		fxchat = (FxChat*)cur->data;
+		if(fxchat->unreadMsgCount != 0)
+			gtk_window_present(GTK_WINDOW(fxchat->dialog));
+
+	}
 }
 gboolean fx_main_register_func(User* user)
 {
@@ -1526,7 +1611,7 @@ gboolean fx_main_check_func(FxMain* fxmain)
 		now_t = mktime(now);
 		msg_time_t = mktime(&(list->message->sendtime));
 		seconds = (long)now_t - (long)msg_time_t;
-		if(seconds > 10) {
+		if(seconds > 20) {
 			unacked_list_remove(unackedlist , list);
 			msg = contruct_message_sip(fxmain->user->sId , list->message);
 			fx_main_process_message(fxmain , fxmain->user->sip , msg);
@@ -1543,39 +1628,7 @@ gboolean fx_main_check_func(FxMain* fxmain)
 
 void fx_main_about_fetion_clicked(GtkWidget *UNUSED(widget) , gpointer UNUSED(data))
 {
-	GtkWidget *dialog = gtk_about_dialog_new();
-	GdkPixbuf *logo = NULL;
-
-	gtk_window_set_modal(GTK_WINDOW(dialog) , TRUE);
-	gtk_about_dialog_set_name(GTK_ABOUT_DIALOG(dialog), "OpenFetion");
-	gtk_about_dialog_set_version(GTK_ABOUT_DIALOG(dialog), FETION_VERSION);
-	gtk_about_dialog_set_copyright(GTK_ABOUT_DIALOG(dialog),
-	"(c) Li Wenpeng");
-	logo = gdk_pixbuf_new_from_file(SKIN_DIR"about.png" , NULL);
-	gtk_window_set_icon(GTK_WINDOW(dialog) , logo);
-	gtk_about_dialog_set_comments(GTK_ABOUT_DIALOG(dialog),
-	_("OpenFetion is a non-profit software, aiming at making linux users convenient to use "
-	"fetion."));
-	gtk_about_dialog_set_website(GTK_ABOUT_DIALOG(dialog),
-	"http://www.basiccoder.com/openfetion");
-	gtk_dialog_run(GTK_DIALOG (dialog));
-	gtk_widget_destroy(dialog);
-}
-
-void fx_main_check_update_clicked(GtkWidget* UNUSED(widget) , gpointer UNUSED(data))
-{
-	if(fork() == 0){
-		execlp("xdg-open" , "xdg-open" , "http://basiccoder.com/openfetion" , (char**)NULL);
-		return;
-	}
-}
-
-void fx_main_about_author_clicked(GtkWidget* UNUSED(widget) , gpointer UNUSED(data))
-{
-	if(fork() == 0){
-		execlp("xdg-open" , "xdg-open" , "http://basiccoder.com" , (char**)NULL);
-		return;
-	}
+	show_about();
 }
 
 void fx_main_send_to_myself_clicked(GtkWidget *widget , gpointer data)
@@ -1787,9 +1840,7 @@ void fx_main_add_history(FxMain *fxmain, const char *name,
 {
 	History   *history;
 	struct tm *now;
-	User      *user;
 
-	user = fxmain->user;
 	now = get_currenttime();
 
 	history = fetion_history_message_new(name
@@ -1829,6 +1880,7 @@ static void fx_main_process_pgpresencechanged(FxMain *fxmain , const char *sipms
 static gboolean key_press_func(GtkWidget *widget , GdkEventKey *event
 		, gpointer data)
 {
+
 	if(event->keyval == GDK_w){
 		if(event->state & GDK_CONTROL_MASK){
 			gtk_window_iconify(GTK_WINDOW(widget));
@@ -1838,7 +1890,11 @@ static gboolean key_press_func(GtkWidget *widget , GdkEventKey *event
 		}
 	}
 	if(event->keyval == GDK_q){
-		if(event->state & GDK_CONTROL_MASK){
+		if(event->state & GDK_CONTROL_MASK) {
+			fx_main_delete(widget , NULL , data);
+			return TRUE;
+		} else if (event->state == GDK_MOD1_MASK) {
+			/* press `command-q` to quit on Mac OS X */
 			fx_main_delete(widget , NULL , data);
 			return TRUE;
 		}else{
