@@ -66,9 +66,10 @@ static void fx_set_on_ok_clicked(GtkWidget *UNUSED(widget) , gpointer data)
 		else
 			config->msgAlert = MSG_ALERT_ENABLE;
 
-		if(gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(fxset->iconBtn)))
+		if(gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(fxset->iconBtn))){
 			config->canIconify = ICON_CAN;
-		else
+			config->closeAlert = CLOSE_ALERT_DISABLE;
+		}else
 			config->canIconify = ICON_CANNOT;
 
 		if(gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(fxset->autoAwayBtn)))
@@ -81,11 +82,21 @@ static void fx_set_on_ok_clicked(GtkWidget *UNUSED(widget) , gpointer data)
 		else
 			config->onlineNotify = ONLINE_NOTIFY_DISABLE;
 
+		if(gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(fxset->closeSysMsgBtn)))
+			config->closeSysMsg = CLOSE_SYSMSG_ENABLE;
+		else
+			config->closeSysMsg = CLOSE_SYSMSG_DISABLE;
+
+		if(gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(fxset->closeShowBtn)))
+			config->closeFetionShow = CLOSE_FETION_SHOW_ENABLE;
+		else
+			config->closeFetionShow = CLOSE_FETION_SHOW_DISABLE;
+
 		gtk_text_buffer_get_start_iter(buffer , &startIter);
 		gtk_text_buffer_get_end_iter(buffer , &endIter);
 		autoReplyMsg = gtk_text_buffer_get_text(buffer , &startIter , &endIter , TRUE);
 
-		bzero(config->autoReplyMessage , sizeof(config->autoReplyMessage));
+		memset(config->autoReplyMessage, 0, sizeof(config->autoReplyMessage));
 
 		if(autoReplyMsg != NULL)
 			strcpy(config->autoReplyMessage , autoReplyMsg);
@@ -94,15 +105,15 @@ static void fx_set_on_ok_clicked(GtkWidget *UNUSED(widget) , gpointer data)
 	else
 	{
 		nickname = gtk_entry_get_text(GTK_ENTRY(fxset->nick_entry));
-		if(strlen(nickname) == 0)
+		if(*nickname == '\0')
 		{
 			fx_util_popup_warning(fxset->fxmain , _("Nick can not be empty!"));
 			return;
 		}
 		impression = gtk_entry_get_text(GTK_ENTRY(fxset->impre_entry));
-		bzero(user->nickname , sizeof(user->nickname));
+		memset(user->nickname, 0, sizeof(user->nickname));
 		strcpy(user->nickname , nickname);
-		bzero(user->impression , sizeof(user->impression));
+		memset(user->impression, 0, sizeof(user->impression));
 		strcpy(user->impression , impression);
 
 		genderModel = gtk_combo_box_get_model(GTK_COMBO_BOX(fxset->gender_combo));
@@ -121,7 +132,7 @@ static void fx_set_on_ok_clicked(GtkWidget *UNUSED(widget) , gpointer data)
 			gtk_label_set_text(GTK_LABEL(fxset->fxmain->headPanel->impre_label)
 					, strlen(user->impression) == 0 ? _("Click here to input signature") : user->impression);
 
-			bzero(fxset->fxmain->headPanel->oldimpression , sizeof(fxset->fxmain->headPanel->oldimpression));
+			memset(fxset->fxmain->headPanel->oldimpression, 0, sizeof(fxset->fxmain->headPanel->oldimpression));
 			strcpy(fxset->fxmain->headPanel->oldimpression
 				, (strlen(user->impression) == 0 || user->impression == NULL)
 				? _("Click here to input signature") : user->impression);
@@ -181,13 +192,13 @@ void fx_set_initialize(FxSet* fxset)
 					 , fxset->notebook , FALSE , FALSE , 0);
 
 	fxset->psetting = gtk_vbox_new(FALSE , FALSE);
-	psetting_label = gtk_label_new(_("Personal setting"));
+	psetting_label = gtk_label_new(_("Personal Settings"));
 	gtk_notebook_append_page(GTK_NOTEBOOK(fxset->notebook)
 						   , fxset->psetting
 						   , psetting_label);
 
 	fxset->ssetting = gtk_vbox_new(FALSE , FALSE);
-	ssetting_label = gtk_label_new(_("System setting"));
+	ssetting_label = gtk_label_new(_("System Settings"));
 	gtk_notebook_append_page(GTK_NOTEBOOK(fxset->notebook)
 						   , fxset->ssetting
 						   , ssetting_label);
@@ -205,7 +216,6 @@ void fx_set_initialize(FxSet* fxset)
 	fx_set_initialize_system(fxset);
 
 	gtk_widget_show_all(fxset->dialog);
-	gtk_widget_hide(fxset->dialog);
 }
 
 void fx_set_bind_system(FxSet* fxset)
@@ -256,6 +266,16 @@ void fx_set_bind_system(FxSet* fxset)
 	else
 		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(fxset->onlineNotifyBtn), FALSE);
 
+	if(config->closeSysMsg == CLOSE_SYSMSG_ENABLE)
+		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(fxset->closeSysMsgBtn), TRUE);
+	else
+		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(fxset->closeSysMsgBtn), FALSE);
+
+	if(config->closeFetionShow == CLOSE_FETION_SHOW_ENABLE)
+		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(fxset->closeShowBtn), TRUE);
+	else
+		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(fxset->closeShowBtn), FALSE);
+
 	buffer = gtk_text_view_get_buffer(GTK_TEXT_VIEW(fxset->apEty));
 	gtk_text_buffer_get_start_iter(buffer , &startIter);
 	gtk_text_buffer_get_end_iter(buffer , &endIter);
@@ -296,7 +316,7 @@ void fx_set_initialize_personal(FxSet* fxset)
 	g_object_unref(pb);
 	gtk_fixed_put(GTK_FIXED(box) , fxset->image , 10 , 15 );
 
-	fxset->sid_label = gtk_label_new(_("Fetion number:"));
+	fxset->sid_label = gtk_label_new(_("Fetion Number:"));
 	gtk_misc_set_alignment(GTK_MISC(fxset->sid_label) , 0 , 0);
 	gtk_fixed_put(GTK_FIXED(box) , fxset->sid_label , 120 , 10 );
 
@@ -316,7 +336,7 @@ void fx_set_initialize_personal(FxSet* fxset)
 	gtk_widget_set_usize(fxset->gender_combo , 150 , 25);
 	gtk_fixed_put(GTK_FIXED(box) , fxset->gender_combo , 310 , 30 );
 
-	fxset->mno_label = gtk_label_new(_("Cell phone number:"));
+	fxset->mno_label = gtk_label_new(_("Cell Phone Number:"));
 	gtk_misc_set_alignment(GTK_MISC(fxset->mno_label) , 0 , 0);
 	gtk_fixed_put(GTK_FIXED(box) , fxset->mno_label , 120 , 60 );
 
@@ -331,7 +351,7 @@ void fx_set_initialize_personal(FxSet* fxset)
 	fxset->nick_entry = gtk_entry_new();
 	gtk_fixed_put(GTK_FIXED(box) , fxset->nick_entry , 310 , 80 );
 
-	fxset->impre_label = gtk_label_new(_("Personal signature:"));
+	fxset->impre_label = gtk_label_new(_("Personal Signature:"));
 	gtk_misc_set_alignment(GTK_MISC(fxset->impre_label) , 0 , 0);
 	gtk_fixed_put(GTK_FIXED(box) , fxset->impre_label , 10 , 115 );
 
@@ -435,40 +455,46 @@ void fx_set_initialize_system(FxSet* fxset)
 
 	label1 = gtk_label_new("");
 	gtk_label_set_markup(GTK_LABEL(label1) , _("<b>Appearance</b>"));
-	gtk_fixed_put(GTK_FIXED(fixed) , label1 , 20 , 20);
+	gtk_fixed_put(GTK_FIXED(fixed) , label1 , 20 , 10);
 	
 	fxset->iconBtn = gtk_check_button_new_with_label(_("Minimize to Tray"));
-	gtk_fixed_put(GTK_FIXED(fixed) , fxset->iconBtn , 40 , 42);
+	gtk_fixed_put(GTK_FIXED(fixed) , fxset->iconBtn , 40 , 32);
 
 	fxset->smallBtn = gtk_check_button_new_with_label(_("Close to Tray"));
-	gtk_fixed_put(GTK_FIXED(fixed) , fxset->smallBtn , 230 , 42);
+	gtk_fixed_put(GTK_FIXED(fixed) , fxset->smallBtn , 230 , 32);
 	
 	fxset->ppCb = gtk_check_button_new_with_label(_("Auto popup message"));
-	gtk_fixed_put(GTK_FIXED(fixed) , fxset->ppCb , 40 , 67);
+	gtk_fixed_put(GTK_FIXED(fixed) , fxset->ppCb , 40 , 57);
 
 	fxset->alertBtn = gtk_check_button_new_with_label(_("Disable Message Notification"));
-	gtk_fixed_put(GTK_FIXED(fixed) , fxset->alertBtn , 230 , 67);
+	gtk_fixed_put(GTK_FIXED(fixed) , fxset->alertBtn , 230 , 57);
 
 	fxset->muteBtn = gtk_check_button_new_with_label(_("Mute"));
-	gtk_fixed_put(GTK_FIXED(fixed) , fxset->muteBtn , 40 , 92);
+	gtk_fixed_put(GTK_FIXED(fixed) , fxset->muteBtn , 40 , 82);
 
 	fxset->autoAwayBtn = gtk_check_button_new_with_label(_("Auto away when idle"));
-	gtk_fixed_put(GTK_FIXED(fixed) , fxset->autoAwayBtn , 230 , 92);
+	gtk_fixed_put(GTK_FIXED(fixed) , fxset->autoAwayBtn , 230 , 82);
 
 	fxset->onlineNotifyBtn = gtk_check_button_new_with_label(_("Online notification enabled"));
-	gtk_fixed_put(GTK_FIXED(fixed) , fxset->onlineNotifyBtn , 40 , 117);
+	gtk_fixed_put(GTK_FIXED(fixed) , fxset->onlineNotifyBtn , 40 , 107);
+
+	fxset->closeSysMsgBtn = gtk_check_button_new_with_label(_("Disable System Message"));
+	gtk_fixed_put(GTK_FIXED(fixed), fxset->closeSysMsgBtn, 230, 107);
+
+	fxset->closeShowBtn = gtk_check_button_new_with_label(_("Disable Fetion Show"));
+	gtk_fixed_put(GTK_FIXED(fixed), fxset->closeShowBtn, 40, 132);
 
 	label2 = gtk_label_new("");
 	gtk_label_set_markup(GTK_LABEL(label2) , _("<b>Auto Reply</b>"));
-	gtk_fixed_put(GTK_FIXED(fixed) , label2 , 20 , 142);
+	gtk_fixed_put(GTK_FIXED(fixed) , label2 , 20 , 162);
 
 	fxset->apBtn = gtk_check_button_new_with_label(_("Enable"));
 	g_signal_connect(fxset->apBtn , "toggled" , G_CALLBACK(fx_set_on_autoreply_toggled) , fxset);
-	gtk_fixed_put(GTK_FIXED(fixed) , fxset->apBtn , 140 , 142);
+	gtk_fixed_put(GTK_FIXED(fixed) , fxset->apBtn , 140 , 162);
 
 	fxset->apEty = gtk_text_view_new();
 	gtk_widget_set_sensitive(fxset->apEty , FALSE);
-	gtk_widget_set_usize(fxset->apEty , 380 , 40);
+	gtk_widget_set_usize(fxset->apEty , 380 , 20);
 	apScr = gtk_scrolled_window_new(NULL , NULL);
 	gtk_container_add(GTK_CONTAINER(apScr) , fxset->apEty);
 	gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(apScr)
@@ -476,17 +502,17 @@ void fx_set_initialize_system(FxSet* fxset)
 								 , GTK_POLICY_NEVER);
 	gtk_scrolled_window_set_shadow_type(GTK_SCROLLED_WINDOW(apScr)
 									  , GTK_SHADOW_ETCHED_IN);
-	gtk_fixed_put(GTK_FIXED(fixed) , apScr , 40 , 165);
+	gtk_fixed_put(GTK_FIXED(fixed) , apScr , 40 , 187);
 
 	label3 = gtk_label_new("");
 	gtk_label_set_markup(GTK_LABEL(label3) , _("<b>Send Message</b>"));
-	gtk_fixed_put(GTK_FIXED(fixed) , label3 , 20 , 212);
+	gtk_fixed_put(GTK_FIXED(fixed) , label3 , 20 , 217);
 
 	fxset->etBtn = gtk_radio_button_new_with_label(NULL , _("Press Enter to Send"));
-	gtk_fixed_put(GTK_FIXED(fixed) , fxset->etBtn , 40 , 230);
+	gtk_fixed_put(GTK_FIXED(fixed) , fxset->etBtn , 40 , 235);
 	gl = gtk_radio_button_get_group(GTK_RADIO_BUTTON(fxset->etBtn));
 	fxset->ctBtn = gtk_radio_button_new_with_label(gl , _("Press CTRL + Enter to Send"));
-	gtk_fixed_put(GTK_FIXED(fixed) , fxset->ctBtn , 40 , 250);
+	gtk_fixed_put(GTK_FIXED(fixed) , fxset->ctBtn , 40 , 255);
 
 	gtk_box_pack_start_defaults(GTK_BOX(fxset->ssetting) , fixed);
 
