@@ -19,7 +19,6 @@
  ***************************************************************************/
 
 #include "fx_include.h"
-#include "time.h"
 /*private*/
 
 static GtkTreeModel* create_model(User* groupList);
@@ -100,7 +99,7 @@ static void show_search(GtkEntry *entry , gpointer data)
 
 	text = gtk_entry_get_text(entry);
 
-	if(text == NULL || strlen(text) == 0)
+	if(text == NULL || *text == '\0')
 		return;
 
 	if(has_gb(text)){
@@ -116,7 +115,7 @@ static void show_search(GtkEntry *entry , gpointer data)
 	fx_search_initialize(search , model , text , x , y);
 }
 
-static void on_search_button_clicked(GtkEntry *entry , void *UNUSED(pos)
+static void on_search_button_clicked(GtkEntry *entry , GtkEntryIconPosition *UNUSED(pos)
 		, GdkEvent *UNUSED(event) , gpointer data)
 {
 	show_search(entry , data);
@@ -307,10 +306,8 @@ void fx_tree_initilize(FxMain* fxmain)
 						"im-module",
 						&value);
 	g_value_unset (&value);
-#ifdef GTK_ENTRY_ICON_SECONDARY
 	gtk_entry_set_icon_from_stock(GTK_ENTRY(fxtree->searchbox)
 			, GTK_ENTRY_ICON_SECONDARY , GTK_STOCK_FIND);
-#endif
 	g_signal_connect(fxtree->searchbox , "icon-press" , G_CALLBACK(on_search_button_clicked) , fxmain);
 	g_signal_connect(fxtree->searchbox , "activate" , G_CALLBACK(show_search) , fxmain);
 	gtk_widget_show_all(fxtree->searchbox);
@@ -423,7 +420,7 @@ static GtkTreeModel* create_model(User* user)
 	GtkTreeStore  *store = NULL;
 	GtkTreeIter    iter;
 	GtkTreeIter    iter1;
-	gchar         *sid;
+	gchar         *sid = NULL;
 	gchar         *name;
 	gchar          path[1024];
 	gint           count;
@@ -629,7 +626,7 @@ static void fx_tree_create_buddy_menu(FxMain* fxmain , GtkWidget* UNUSED(tree)
 		chatargs = fx_args_new(fxmain , iter , sipuri , 0);
 		fx_tree_create_menu(_("Send IM mesages") , SKIN_DIR"myselfsms.png" , menu
 						  , ((serviceStatus == BASIC_SERVICE_ABNORMAL
-								  && (carrierStatus == CARRIER_STATUS_CLOSED || (strlen(carrier)!= 0 && strlen(mobileno) == 0)))
+								  && (carrierStatus == CARRIER_STATUS_CLOSED || (*carrier != '\0' && *mobileno == '\0')))
 						  || relationStatus == RELATION_STATUS_UNAUTHENTICATED || user->state == P_OFFLINE)
 						  ? FALSE : TRUE
 						  , fx_tree_on_chatmenu_clicked , chatargs);
@@ -637,7 +634,7 @@ static void fx_tree_create_buddy_menu(FxMain* fxmain , GtkWidget* UNUSED(tree)
 		fx_tree_create_menu(_("view contact's information") , SKIN_DIR"profile.png"
 						, menu , (serviceStatus == BASIC_SERVICE_ABNORMAL
 						  && (carrierStatus == CARRIER_STATUS_CLOSED ||
-							  (strlen(carrier)!= 0 && strlen(mobileno) == 0))) ?
+							  (*carrier != '\0' && *mobileno == '\0'))) ?
 						FALSE : TRUE , fx_tree_on_profilemenu_clicked , profileargs);
 #if 0
 		fx_tree_create_menu("FILE" , SKIN_DIR"sendfile.png"
@@ -689,10 +686,10 @@ static void fx_tree_create_buddy_menu(FxMain* fxmain , GtkWidget* UNUSED(tree)
 		}
 	}
 	gtk_widget_show_all(menu);
-	free(userid);
-	free(sipuri);
-	free(mobileno);
-	free(carrier);
+	g_free(userid);
+	g_free(sipuri);
+	g_free(mobileno);
+	g_free(carrier);
 	gtk_menu_popup(GTK_MENU(menu) , NULL , NULL , NULL , NULL
 			, (event != NULL) ? event->button : 0 , gdk_event_get_time((GdkEvent*)event));
 }
@@ -826,7 +823,7 @@ static void fx_tree_text_cell_data_func(GtkTreeViewColumn *UNUSED(col),
 	/* render friend list text*/
 	if(gtk_tree_path_get_depth(path) > 1)
 	{
-		bzero(text , sizeof(text));
+		memset(text, 0, sizeof(text));
 		gtk_tree_model_get(model         , iter
 						, B_NAME_COL       , &name
 						, B_SIPURI_COL     , &sipuri
@@ -854,7 +851,7 @@ static void fx_tree_text_cell_data_func(GtkTreeViewColumn *UNUSED(col),
 				if(carrier != NULL || strlen(carrier) != 0){
 					snprintf(statusStr , sizeof(statusStr) - 1,
 								 _("<span color='#d4b4b4'>[Online with SMS]</span>"));
-					if(mobileno == NULL || strlen(mobileno) == 0){
+					if(mobileno == NULL || *mobileno == '\0'){
 						snprintf(statusStr , sizeof(statusStr) - 1,
 									 _("<span color='#d4b4b4'>[Has shut fetion service]</span>"));
 					}
@@ -864,7 +861,7 @@ static void fx_tree_text_cell_data_func(GtkTreeViewColumn *UNUSED(col),
 				}
 			}
 		}else if(carrierStatus == CARRIER_STATUS_DOWN){
-			if(strlen(carrier) != 0){
+			if(*carrier != '\0'){
 				snprintf(statusStr , sizeof(statusStr) - 1,
 							   	_("<span color='#d4b4b4'>[Out of service]</span>"));
 			}
@@ -884,7 +881,7 @@ static void fx_tree_text_cell_data_func(GtkTreeViewColumn *UNUSED(col),
         snprintf(text , sizeof(text) - 1 , "<b>%s</b>%s%s"
                        "(%s) %s <span color='#838383'>%s</span>"
                        , name == NULL ? "" : name
-                       , (strlen(statusStr) == 0 ? (presence == 0 ? "" : stateStr1) : statusStr)
+                       , (*statusStr == '\0' ? (presence == 0 ? "" : stateStr1) : statusStr)
                        , (device != NULL && strcmp(device , "PC") != 0) ? _("[Login with cell phone]") : "", sid, newline
                        , impression == NULL ? "" : impression);
 		g_object_set(renderer, "markup", text, NULL);
@@ -901,7 +898,7 @@ static void fx_tree_text_cell_data_func(GtkTreeViewColumn *UNUSED(col),
 	/*render group list text*/
 	else
 	{
-		bzero(text , sizeof(text));
+		memset(text, 0, sizeof(text));
 		gtk_tree_model_get(model              , iter
 						 , G_NAME_COL         , &buddylistName
 						 , G_ALL_COUNT_COL    , &allCount
@@ -1125,6 +1122,15 @@ static void fx_tree_on_double_click(GtkTreeView *treeview
 	gchar *sipuri , *mobileno , *carrier;
 	gint serviceStatus , relationStatus , carrierStatus;
 
+	FxList        *mlist;
+	FxList        *cur;
+	FxList        *tmp;
+	FxChat        *fxchat;
+	Message       *msg;
+
+	mlist = fxmain->mlist;
+	cur = mlist->pre;
+
 	if(depth > 1){
 		if(!fx_conn_check_action(fxmain))
 			return;
@@ -1143,20 +1149,40 @@ static void fx_tree_on_double_click(GtkTreeView *treeview
 		}
 		if(serviceStatus == BASIC_SERVICE_ABNORMAL &&
 			(carrierStatus == CARRIER_STATUS_CLOSED ||
-			 (strlen(carrier) != 0 && strlen(mobileno) == 0)))
+			 (*carrier != '\0' && *mobileno == '\0')))
 		{
 			fx_util_popup_warning(fxmain , _("This user have shut fetion service,so you cannot send mesage to him/her"));
 			return;
 		}
+
+		while(cur != fxmain->mlist){
+			msg = (Message*)(cur->data);
+
+			/* ordinary message */
+			if(!msg->pguri && strcmp(sipuri, msg->sipuri) == 0){
+				fxchat = fx_main_create_chat_window(fxmain , msg->sipuri);
+
+				if(!fxchat){
+					g_print("Unknow Message\n");
+					g_print("%s:%s\n" , msg->sipuri ,  msg->message);
+					continue;
+				}
+				fx_chat_add_message(fxchat , msg->message,
+						&(msg->sendtime) , 0 , msg->sysback);
+				fetion_message_free(msg);
+				tmp = cur;
+				cur = cur->pre;
+				fx_list_remove(tmp);
+				g_free(tmp);
+			}else{
+				cur = cur->pre;
+			}
+		}
+
 		fx_main_create_chat_window(fxmain , sipuri);
 		g_free(sipuri);
 		g_free(mobileno);
 		g_free(carrier);
-	}else{
-		if(gtk_tree_view_row_expanded(treeview , path))
-			gtk_tree_view_collapse_row(treeview , path);
-		else
-			gtk_tree_view_expand_row(treeview , path , TRUE);
 	}
 }
 static gboolean fx_tree_on_rightbutton_click(GtkWidget* UNUSED(tree)
@@ -1167,10 +1193,10 @@ static gboolean fx_tree_on_rightbutton_click(GtkWidget* UNUSED(tree)
 	GtkTreeModel *model = NULL;
 	FxMain       *fxmain = NULL;
 	FxTree       *fxtree = NULL;
-	int depth;
 
-	if(event->type == GDK_BUTTON_PRESS && event->button == 3)
+	if(event->type == GDK_BUTTON_PRESS)
 	{
+		int depth;
 
 		fxmain = (FxMain*)data;
 		fxtree = fxmain->mainPanel;
@@ -1184,13 +1210,24 @@ static gboolean fx_tree_on_rightbutton_click(GtkWidget* UNUSED(tree)
 			return FALSE;
 
 		depth = gtk_tree_path_get_depth(path);
-		if(depth == 2){
-			fx_tree_create_buddy_menu(fxmain , fxtree->treeView , path , event , iter);
-		}else{
-			fx_tree_create_group_menu(fxmain , fxtree->treeView , event , iter);
+
+		if(event->button == 3){
+			if(depth == 2)
+				fx_tree_create_buddy_menu(fxmain , fxtree->treeView , path , event , iter);
+			else
+				fx_tree_create_group_menu(fxmain , fxtree->treeView , event , iter);
+			
+			gtk_tree_path_free(path);
+			return TRUE;
+		}else if(event->button == 1){
+			if(depth == 2)
+				return FALSE;
+			if(gtk_tree_view_row_expanded(GTK_TREE_VIEW(fxtree->treeView) , path))
+				gtk_tree_view_collapse_row(GTK_TREE_VIEW(fxtree->treeView) , path);
+			else
+				gtk_tree_view_expand_row(GTK_TREE_VIEW(fxtree->treeView) , path , TRUE);
+			return TRUE;
 		}
-		gtk_tree_path_free(path);
-		return TRUE;
 	}
 	return FALSE;
 }
@@ -1215,9 +1252,11 @@ static void* update_contact_info(void *data)
 	gdk_threads_enter();
 	res = fetion_config_get_province_name(contact->province);
 	gtk_entry_set_text(GTK_ENTRY(fxprofile->province_entry) , res == NULL ? _("Unknown") : res);
+	update();
 	free(res);
 	res = fetion_config_get_city_name(contact->province , contact->city);
 	gtk_entry_set_text(GTK_ENTRY(fxprofile->city_entry) , res == NULL ? _("Unknown") : res);
+	update();
 	free(res);
 	gdk_threads_leave();
 
@@ -1241,7 +1280,7 @@ static void fx_tree_on_profilemenu_clicked(GtkWidget* UNUSED(widget) , gpointer
 
 	if(contact){
 		fx_profile_bind(fxprofile , contact);
-		if(strlen(contact->province) == 0)
+		if(strlen(contact->province) == 0 && fxmain->user->state != P_OFFLINE)
 			g_thread_create(update_contact_info, fxprofile, FALSE, NULL);
 	}
 
@@ -1528,7 +1567,7 @@ static void fx_tree_on_movemenu_clicked(GtkWidget* UNUSED(widget) , gpointer dat
 	gint           gid , oldOnlineCount , oldAllCount , newOnlineCount , newAllCount;
 	GdkPixbuf     *pb = NULL;
 
-	if(fetion_contact_move_to_group(fxmain->user , userid , groupid) > 0)
+	if(fetion_contact_move_to_group(fxmain->user , userid , groupid) == 0)
 	{
 		gtk_tree_model_get_iter_root(model , &parentIter);
 		do
@@ -1672,22 +1711,22 @@ static gboolean fx_tree_on_show_tooltip(GtkWidget* widget
 					 , B_RELATIONSTATUS_COL , &relationStatus
 					 , -1);
 	sid = fetion_sip_get_sid_by_sipuri(sipuri);
-	bzero(phonetext , sizeof(phonetext));
+	memset(phonetext, 0, sizeof(phonetext));
 	if(carrierStatus == CARRIER_STATUS_DOWN){
 
-		if(strlen(carrier) == 0)
+		if(*carrier == '\0')
 			snprintf(phonetext, sizeof(phonetext) - 1,
 					_("<span color='#0088bf'>Not bind to a phone number.</span>"));
 		else
 			snprintf(phonetext, sizeof(phonetext) - 1,
 					_("<span color='#0088bf'>%s</span>(<b>Out of service</b>)")
-					, strlen(mobileno) == 0 ? _("Phone number not be published.") : mobileno);
+					, *mobileno == '\0' ? _("Phone number not be published.") : mobileno);
 
 	}else if (carrierStatus == CARRIER_STATUS_NORMAL){
 		snprintf(phonetext, sizeof(phonetext) - 1,
 				"<span color='#0088bf'>%s</span>"
-				, (carrier == NULL || strlen(carrier) == 0) ? _("Not bind to a phone number.")
-				: (mobileno == NULL || strlen(mobileno) == 0 ? _("Phone number not be published.") : mobileno));
+				, (carrier == NULL || *carrier == '\0') ? _("Not bind to a phone number.")
+				: (mobileno == NULL || *mobileno == '\0' ? _("Phone number not be published.") : mobileno));
 	}
 	snprintf(text , sizeof(text) - 1 ,
 				   	_(" <span color='#808080'>Nickname:</span>  <b>%s</b>\n"
@@ -1708,7 +1747,7 @@ static gboolean fx_tree_on_show_tooltip(GtkWidget* widget
 	g_free(sid);
 	pb = gdk_pixbuf_new_from_file_at_size(iconpath , 80 , 80 , NULL);
 	if(pb == NULL)
-		pb = gdk_pixbuf_new_from_file_at_size(SKIN_DIR"fetion.svg" , 80 , 80 , NULL);
+		pb = gdk_pixbuf_new_from_file_at_size(SKIN_DIR"portrait.png" , 80 , 80 , NULL);
 	gtk_tooltip_set_markup(tip , text);
 	gtk_tooltip_set_icon(tip , pb);
 	g_object_unref(pb);
@@ -1745,13 +1784,12 @@ static void pg_on_double_click(GtkTreeView *treeview
 		, GtkTreePath *path , GtkTreeViewColumn  *UNUSED(col) , gpointer data)
 {
 	FxMain* fxmain = (FxMain*)data;
-    	FxPGGroup *fxpg;
 	GtkTreeIter iter;
 	char *pguri;
 	GtkTreeModel* model = gtk_tree_view_get_model(GTK_TREE_VIEW(treeview));
 	gtk_tree_model_get_iter(model , &iter , path);
 	gtk_tree_model_get(model , &iter , PG_URI_COL , &pguri , -1);
-	fxpg = pg_create_window(fxmain , pguri);
+	pg_create_window(fxmain , pguri);
 	free(pguri);
 }
 
