@@ -53,6 +53,9 @@ char* fx_util_get_state_name(StateType type)
 		case P_ONTHEPHONE:
 			strcpy(name , _("[Calling]"));
 			break;
+		case P_OFFLINE:
+			strcpy(name, _("[Offline]"));
+			break;
 		default:
 			if(type > 400 && type < 500)
 				strcpy(name , _("[Online]"));
@@ -68,7 +71,7 @@ void fx_util_popup_warning(FxMain* fxmain , const char* message)
 	dialog = gtk_message_dialog_new(GTK_WINDOW(fxmain->window),
 									GTK_DIALOG_DESTROY_WITH_PARENT,
 									GTK_MESSAGE_WARNING,
-									GTK_BUTTONS_OK,
+									GTK_BUTTONS_OK,"%s",
 									message);
 	gtk_window_set_title(GTK_WINDOW(dialog), "Warning");
 	gtk_dialog_run(GTK_DIALOG(dialog));
@@ -302,6 +305,8 @@ char *fx_util_replace_emotion(char *str)
 
 void escape_impression(char *impre)
 {
+	if(!impre)
+		return;
 	int i;
 	for(i = 0 ; i < strlen(impre); i++){
 		if(impre[i] == 10 || impre[i] == 13)
